# cenROCTest
<p align="center">

<a href="https://pypi.python.org/pypi/cenroctest">
<img src="https://img.shields.io/pypi/v/cenroctest.svg" /></a>
<a href="https://travis-ci.org/YuryMoskaltsov/cenroctest"><img src="https://travis-ci.org/YuryMoskaltsov/cenroctest.svg?branch=master" /></a>
</p>
Calculates cenROC 

## Features
-   TODO

# Credits
This package was created with Cookiecutter and the `cs01/cookiecutter-pypackage` project template.

[Cookiecutter](https://github.com/audreyr/cookiecutter)

[cs01/cookiecutter-pypackage](https://github.com/cs01/cookiecutter-pypackage)
